# wikitude-studio-api-client
The Wikitude Studio API is a RESTful API which is used to
* organize and manipulate projects and its targets
* create wtc/wto files which can be used to create trackers in the Wikitude SDK with the JavaScript API
* generate/publish a cloud archive to the cloud recognition service (image targets only)

Download API clients:
* [`OpenAPI 3.0`](https://www.wikitude.com/external/doc/documentation/studio-api/clients/wikitude_studio_api_client-openapi.zip)
* [`JavaScript`](https://www.wikitude.com/external/doc/documentation/studio-api/clients/wikitude_studio_api_client-javascript.zip)
* [`Python`](https://www.wikitude.com/external/doc/documentation/studio-api/clients/wikitude_studio_api_client-python.zip)
* [`PHP`](https://www.wikitude.com/external/doc/documentation/studio-api/clients/wikitude_studio_api_client-php.zip)
* [`TypeScript (NodeJS)`](https://www.wikitude.com/external/doc/documentation/studio-api/clients/wikitude_studio_api_client-typescript-node.zip)
* [`Java`](https://www.wikitude.com/external/doc/documentation/studio-api/clients/wikitude_studio_api_client-java.zip)
* [`Ruby`](https://www.wikitude.com/external/doc/documentation/studio-api/clients/wikitude_studio_api_client-ruby.zip)
* [`C# .NET Core`](https://www.wikitude.com/external/doc/documentation/studio-api/clients/wikitude_studio_api_client-csharp-netcore.zip)

This technical reference formally explains various API endpoints.
Visit the [`Studio API documentation`](https://www.wikitude.com/external/doc/documentation/studio/) for a more general description.


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 3.0.0
- Package version: 3.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python >= 3.6

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import wikitude_studio_api_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import wikitude_studio_api_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import wikitude_studio_api_client
from pprint import pprint
from wikitude_studio_api_client.api import account_api
from wikitude_studio_api_client.model.get_account_info_response import GetAccountInfoResponse
# Defining the host is optional and defaults to https://api-eu.wikitude.com/cloudrecognition
# See configuration.py for a list of all supported configuration parameters.
configuration = wikitude_studio_api_client.Configuration(
    host = "https://api-eu.wikitude.com/cloudrecognition"
)



# Enter a context with an instance of the API client
with wikitude_studio_api_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = account_api.AccountApi(api_client)
    x_version = "3" # str | The version of the API to be used. Must be set to 3.
x_token = "X-Token_example" # str | Your Manager Token.

    try:
        # Get account information
        api_response = api_instance.get_account(x_version, x_token)
        pprint(api_response)
    except wikitude_studio_api_client.ApiException as e:
        print("Exception when calling AccountApi->get_account: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://api-eu.wikitude.com/cloudrecognition*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccountApi* | [**get_account**](docs/AccountApi.md#get_account) | **GET** /account | Get account information
*HeatmapApi* | [**generate_heatmap**](docs/HeatmapApi.md#generate_heatmap) | **POST** /heatmap | Generate Heatmap
*HeatmapApi* | [**get_heatmap_status**](docs/HeatmapApi.md#get_heatmap_status) | **GET** /heatmap/{generationId} | Status - Generate Heatmap
*ImageTargetApi* | [**create_image_targets**](docs/ImageTargetApi.md#create_image_targets) | **POST** /targetCollection/{tcId}/targets | Create Image Targets
*ImageTargetApi* | [**delete_image_target**](docs/ImageTargetApi.md#delete_image_target) | **DELETE** /targetCollection/{tcId}/target/{targetId} | Delete Image Target
*ImageTargetApi* | [**get_image_target**](docs/ImageTargetApi.md#get_image_target) | **GET** /targetCollection/{tcId}/target/{targetId} | Get Image Target
*ImageTargetApi* | [**get_image_target_status**](docs/ImageTargetApi.md#get_image_target_status) | **GET** /targetCollection/{tcId}/generation/targets/{generationId} | Status - Image Targets Creation
*ImageTargetApi* | [**get_image_targets**](docs/ImageTargetApi.md#get_image_targets) | **GET** /targetCollection/{tcId}/target | Get Image Targets
*ImageTargetApi* | [**update_image_target**](docs/ImageTargetApi.md#update_image_target) | **POST** /targetCollection/{tcId}/target/{targetId} | Update Image Target
*ImageTargetCollectionApi* | [**create_image_target_collection**](docs/ImageTargetCollectionApi.md#create_image_target_collection) | **POST** /targetCollection | Create Image Target Collection
*ImageTargetCollectionApi* | [**delete_image_target_collection**](docs/ImageTargetCollectionApi.md#delete_image_target_collection) | **DELETE** /targetCollection/{tcId} | Delete Image Target Collection
*ImageTargetCollectionApi* | [**generate_cloud_archive**](docs/ImageTargetCollectionApi.md#generate_cloud_archive) | **POST** /targetCollection/{tcId}/generation/cloudarchive | Generate Cloud Archive
*ImageTargetCollectionApi* | [**generate_wtc**](docs/ImageTargetCollectionApi.md#generate_wtc) | **POST** /targetCollection/{tcId}/generation/wtc | Generate WTC
*ImageTargetCollectionApi* | [**get_cloud_archive_status**](docs/ImageTargetCollectionApi.md#get_cloud_archive_status) | **GET** /targetCollection/{tcId}/generation/cloudarchive/{generationId} | Status - Generate Cloud Archive
*ImageTargetCollectionApi* | [**get_image_target_collection**](docs/ImageTargetCollectionApi.md#get_image_target_collection) | **GET** /targetCollection/{tcId} | Get Image Target Collection
*ImageTargetCollectionApi* | [**get_image_target_collections**](docs/ImageTargetCollectionApi.md#get_image_target_collections) | **GET** /targetCollection | Get all Image Target Collections
*ImageTargetCollectionApi* | [**get_similarity_check_status**](docs/ImageTargetCollectionApi.md#get_similarity_check_status) | **GET** /targetCollection/{tcId}/similarity/{generationId} | Status - Similarity Check
*ImageTargetCollectionApi* | [**get_wtc_status**](docs/ImageTargetCollectionApi.md#get_wtc_status) | **GET** /targetCollection/{tcId}/generation/wtc/{generationId} | Status - Generate WTC
*ImageTargetCollectionApi* | [**similarity_check**](docs/ImageTargetCollectionApi.md#similarity_check) | **POST** /targetCollection/{tcId}/similarity | Similarity Check
*ImageTargetCollectionApi* | [**update_image_target_collection**](docs/ImageTargetCollectionApi.md#update_image_target_collection) | **POST** /targetCollection/{tcId} | Update Image Target Collection
*ObjectTargetApi* | [**create_object_target_from_images**](docs/ObjectTargetApi.md#create_object_target_from_images) | **POST** /objectTargetCollection/{tcId}/target/images | Create Object Target from Images
*ObjectTargetApi* | [**create_object_target_from_wto**](docs/ObjectTargetApi.md#create_object_target_from_wto) | **POST** /objectTargetCollection/{tcId}/target/wto | Create Object Target from WTO
*ObjectTargetApi* | [**delete_object_target**](docs/ObjectTargetApi.md#delete_object_target) | **DELETE** /objectTargetCollection/{tcId}/target/{targetId} | Delete Object Target
*ObjectTargetApi* | [**extend_object_target**](docs/ObjectTargetApi.md#extend_object_target) | **PUT** /objectTargetCollection/{tcId}/target/{targetId} | Extend Object Target
*ObjectTargetApi* | [**get_object_target**](docs/ObjectTargetApi.md#get_object_target) | **GET** /objectTargetCollection/{tcId}/target/{targetId} | Get Object Target
*ObjectTargetApi* | [**get_object_target_status**](docs/ObjectTargetApi.md#get_object_target_status) | **GET** /objectTargetCollection/{tcId}/generation/targets/{generationId} | Status - Object Target Generation Information
*ObjectTargetApi* | [**get_object_targets**](docs/ObjectTargetApi.md#get_object_targets) | **GET** /objectTargetCollection/{tcId}/target | Get Object Targets
*ObjectTargetApi* | [**rename_object_target**](docs/ObjectTargetApi.md#rename_object_target) | **PUT** /objectTargetCollection/{tcId}/target/{targetId}/name | Rename Object Target
*ObjectTargetCollectionApi* | [**create_object_target_collection**](docs/ObjectTargetCollectionApi.md#create_object_target_collection) | **POST** /objectTargetCollection | Create Object Target Collection
*ObjectTargetCollectionApi* | [**delete_object_target_collection**](docs/ObjectTargetCollectionApi.md#delete_object_target_collection) | **DELETE** /objectTargetCollection/{tcId} | Delete Object Target Collection
*ObjectTargetCollectionApi* | [**generate_wto**](docs/ObjectTargetCollectionApi.md#generate_wto) | **POST** /objectTargetCollection/{tcId}/generation/wto | Generate WTO
*ObjectTargetCollectionApi* | [**get_object_target_collection**](docs/ObjectTargetCollectionApi.md#get_object_target_collection) | **GET** /objectTargetCollection/{tcId} | Get Object Target Collection
*ObjectTargetCollectionApi* | [**get_object_target_collection_status**](docs/ObjectTargetCollectionApi.md#get_object_target_collection_status) | **GET** /objectTargetCollection/{tcId}/jobs | Status - Get Object Target Collection jobs
*ObjectTargetCollectionApi* | [**get_object_target_collections**](docs/ObjectTargetCollectionApi.md#get_object_target_collections) | **GET** /objectTargetCollection | Get all Object Target Collections
*ObjectTargetCollectionApi* | [**get_wto_status**](docs/ObjectTargetCollectionApi.md#get_wto_status) | **GET** /objectTargetCollection/{tcId}/generation/wto/{generationId} | Status - Generate WTO
*ObjectTargetCollectionApi* | [**update_object_target_collection**](docs/ObjectTargetCollectionApi.md#update_object_target_collection) | **PUT** /objectTargetCollection/{tcId} | Update Object Target Collection
*ProjectApi* | [**get_projects**](docs/ProjectApi.md#get_projects) | **GET** /projects | Get all projects


## Documentation For Models

 - [CloudArchiveGenerationResponse](docs/CloudArchiveGenerationResponse.md)
 - [CloudArchiveGenerationResponseInputParams](docs/CloudArchiveGenerationResponseInputParams.md)
 - [CreateImageTargetCollectionBody](docs/CreateImageTargetCollectionBody.md)
 - [CreateImageTargetCollectionBodyCloudArchive](docs/CreateImageTargetCollectionBodyCloudArchive.md)
 - [CreateImageTargetsBody](docs/CreateImageTargetsBody.md)
 - [CreateImageTargetsResponse](docs/CreateImageTargetsResponse.md)
 - [CreateImageTargetsResponseInputParams](docs/CreateImageTargetsResponseInputParams.md)
 - [CreateImageTargetsResponseInputParamsTargets](docs/CreateImageTargetsResponseInputParamsTargets.md)
 - [CreateObjectTargetCollectionBody](docs/CreateObjectTargetCollectionBody.md)
 - [CreateObjectTargetImagesBody](docs/CreateObjectTargetImagesBody.md)
 - [CreateObjectTargetImagesBodyResource](docs/CreateObjectTargetImagesBodyResource.md)
 - [CreateObjectTargetWTOBody](docs/CreateObjectTargetWTOBody.md)
 - [CreateObjectTargetWTOBodyResource](docs/CreateObjectTargetWTOBodyResource.md)
 - [ExtendObjectTargetBody](docs/ExtendObjectTargetBody.md)
 - [GenerateHeatmapBody](docs/GenerateHeatmapBody.md)
 - [GenerateHeatmapResponse](docs/GenerateHeatmapResponse.md)
 - [GenerateHeatmapResponseInputParams](docs/GenerateHeatmapResponseInputParams.md)
 - [GenerateHeatmapStatusResponse](docs/GenerateHeatmapStatusResponse.md)
 - [GenerateHeatmapStatusResponsePayload](docs/GenerateHeatmapStatusResponsePayload.md)
 - [GenerateWTCBody](docs/GenerateWTCBody.md)
 - [GenerateWTCStatusResponse](docs/GenerateWTCStatusResponse.md)
 - [GenerateWTOBody](docs/GenerateWTOBody.md)
 - [GetAccountInfoResponse](docs/GetAccountInfoResponse.md)
 - [GetAccountInfoResponseStorage](docs/GetAccountInfoResponseStorage.md)
 - [ImageTargetCollectionResponse](docs/ImageTargetCollectionResponse.md)
 - [ImageTargetCollectionResponseCloudArchive](docs/ImageTargetCollectionResponseCloudArchive.md)
 - [ImageTargetCollectionResponseWtc](docs/ImageTargetCollectionResponseWtc.md)
 - [ImageTargetResponse](docs/ImageTargetResponse.md)
 - [ObjectTargetCollectionJobResponse](docs/ObjectTargetCollectionJobResponse.md)
 - [ObjectTargetCollectionResponse](docs/ObjectTargetCollectionResponse.md)
 - [ObjectTargetCollectionResponseWto](docs/ObjectTargetCollectionResponseWto.md)
 - [ObjectTargetJobResponse](docs/ObjectTargetJobResponse.md)
 - [ObjectTargetResponse](docs/ObjectTargetResponse.md)
 - [ObjectTargetResponseResource](docs/ObjectTargetResponseResource.md)
 - [ObjectTargetResponseWtoFile](docs/ObjectTargetResponseWtoFile.md)
 - [RenameObjectTargetBody](docs/RenameObjectTargetBody.md)
 - [SimilarityCheckBody](docs/SimilarityCheckBody.md)
 - [SimilarityCheckBodyImages](docs/SimilarityCheckBodyImages.md)
 - [SimilarityCheckResponse](docs/SimilarityCheckResponse.md)
 - [SimilarityCheckResponseInputParams](docs/SimilarityCheckResponseInputParams.md)
 - [SimilarityCheckResponseInputParamsImages](docs/SimilarityCheckResponseInputParamsImages.md)
 - [SimilarityCheckStatusResponse](docs/SimilarityCheckStatusResponse.md)
 - [SimilarityCheckStatusResponseCandidates](docs/SimilarityCheckStatusResponseCandidates.md)
 - [SimilarityCheckStatusResponseInputParams](docs/SimilarityCheckStatusResponseInputParams.md)
 - [SimilarityCheckStatusResponsePayload](docs/SimilarityCheckStatusResponsePayload.md)
 - [UpdateImageTargetBody](docs/UpdateImageTargetBody.md)
 - [UpdateImageTargetCollectionBody](docs/UpdateImageTargetCollectionBody.md)
 - [UpdateObjectTargetCollectionBody](docs/UpdateObjectTargetCollectionBody.md)


## Documentation For Authorization

 All endpoints do not require authorization.

## Author




## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in wikitude_studio_api_client.apis and wikitude_studio_api_client.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from wikitude_studio_api_client.api.default_api import DefaultApi`
- `from wikitude_studio_api_client.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import wikitude_studio_api_client
from wikitude_studio_api_client.apis import *
from wikitude_studio_api_client.models import *
```

