# wikitude_studio_api_client.HeatmapApi

All URIs are relative to *https://api-eu.wikitude.com/cloudrecognition*

Method | HTTP request | Description
------------- | ------------- | -------------
[**generate_heatmap**](HeatmapApi.md#generate_heatmap) | **POST** /heatmap | Generate Heatmap
[**get_heatmap_status**](HeatmapApi.md#get_heatmap_status) | **GET** /heatmap/{generationId} | Status - Generate Heatmap


# **generate_heatmap**
> GenerateHeatmapResponse generate_heatmap(x_version, x_token, content_type, generate_heatmap_body)

Generate Heatmap

Generates a greyscale image out of the input image, where areas with recognition and tracking relevance are highlighted in color. This way one can better understand the rating of an image and see which areas have the highest importance for 2D recognition and tracking. Note that only JPG and non-transparent PNG files are accepted and the generated heatmap image is stored on a temporary folder which is deleted after 24 hours. Store the image on your own server in case you plan to use it in your user interface. 

### Example

```python
import time
import wikitude_studio_api_client
from wikitude_studio_api_client.api import heatmap_api
from wikitude_studio_api_client.model.generate_heatmap_body import GenerateHeatmapBody
from wikitude_studio_api_client.model.generate_heatmap_response import GenerateHeatmapResponse
from pprint import pprint
# Defining the host is optional and defaults to https://api-eu.wikitude.com/cloudrecognition
# See configuration.py for a list of all supported configuration parameters.
configuration = wikitude_studio_api_client.Configuration(
    host = "https://api-eu.wikitude.com/cloudrecognition"
)


# Enter a context with an instance of the API client
with wikitude_studio_api_client.ApiClient() as api_client:
    # Create an instance of the API class
    api_instance = heatmap_api.HeatmapApi(api_client)
    x_version = "3" # str | The version of the API to be used. Must be set to 3.
    x_token = "X-Token_example" # str | Your Manager Token.
    content_type = "Content-Type_example" # str | The Content Type of the body. Must be set to application/json.
    generate_heatmap_body = GenerateHeatmapBody(
        image_url="https://wikitudeUrl.com/img.jpg",
    ) # GenerateHeatmapBody | 

    # example passing only required values which don't have defaults set
    try:
        # Generate Heatmap
        api_response = api_instance.generate_heatmap(x_version, x_token, content_type, generate_heatmap_body)
        pprint(api_response)
    except wikitude_studio_api_client.ApiException as e:
        print("Exception when calling HeatmapApi->generate_heatmap: %s\n" % e)
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **x_version** | **str**| The version of the API to be used. Must be set to 3. |
 **x_token** | **str**| Your Manager Token. |
 **content_type** | **str**| The Content Type of the body. Must be set to application/json. |
 **generate_heatmap_body** | [**GenerateHeatmapBody**](GenerateHeatmapBody.md)|  |

### Return type

[**GenerateHeatmapResponse**](GenerateHeatmapResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | successful operation |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID  |  -  |
**401** | INVALID_TOKEN |  -  |
**404** | TARGET_COLLECTION_NOT_FOUND&lt;br/&gt; TARGET_NOT_FOUND  |  -  |
**500** | INTERNAL_SERVER_ERROR |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_heatmap_status**
> GenerateHeatmapStatusResponse get_heatmap_status(x_version, x_token, generation_id)

Status - Generate Heatmap

Retrieves information status about a particular scheduled heatmap creation.

### Example

```python
import time
import wikitude_studio_api_client
from wikitude_studio_api_client.api import heatmap_api
from wikitude_studio_api_client.model.generate_heatmap_status_response import GenerateHeatmapStatusResponse
from pprint import pprint
# Defining the host is optional and defaults to https://api-eu.wikitude.com/cloudrecognition
# See configuration.py for a list of all supported configuration parameters.
configuration = wikitude_studio_api_client.Configuration(
    host = "https://api-eu.wikitude.com/cloudrecognition"
)


# Enter a context with an instance of the API client
with wikitude_studio_api_client.ApiClient() as api_client:
    # Create an instance of the API class
    api_instance = heatmap_api.HeatmapApi(api_client)
    x_version = "3" # str | The version of the API to be used. Must be set to 3.
    x_token = "X-Token_example" # str | Your Manager Token.
    generation_id = "generationId_example" # str | Unique identifier of the asynchronous job created by a generation endpoint.

    # example passing only required values which don't have defaults set
    try:
        # Status - Generate Heatmap
        api_response = api_instance.get_heatmap_status(x_version, x_token, generation_id)
        pprint(api_response)
    except wikitude_studio_api_client.ApiException as e:
        print("Exception when calling HeatmapApi->get_heatmap_status: %s\n" % e)
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **x_version** | **str**| The version of the API to be used. Must be set to 3. |
 **x_token** | **str**| Your Manager Token. |
 **generation_id** | **str**| Unique identifier of the asynchronous job created by a generation endpoint. |

### Return type

[**GenerateHeatmapStatusResponse**](GenerateHeatmapStatusResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The requested job information, including \&quot;status\&quot;, \&quot;payload\&quot; attribute, \&quot;estimatedEnd\&quot;, \&quot;estimatedLatency\&quot; attributes. The \&quot;payload\&quot; contains a url to the generated heatmap or or an \&quot;error\&quot;-object.  |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID  |  -  |
**401** | INVALID_TOKEN  |  -  |
**404** | GENERATION_NOT_FOUND  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

