# wikitude_studio_api_client.ImageTargetApi

All URIs are relative to *https://api-eu.wikitude.com/cloudrecognition*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create_image_targets**](ImageTargetApi.md#create_image_targets) | **POST** /targetCollection/{tcId}/targets | Create Image Targets
[**delete_image_target**](ImageTargetApi.md#delete_image_target) | **DELETE** /targetCollection/{tcId}/target/{targetId} | Delete Image Target
[**get_image_target**](ImageTargetApi.md#get_image_target) | **GET** /targetCollection/{tcId}/target/{targetId} | Get Image Target
[**get_image_target_status**](ImageTargetApi.md#get_image_target_status) | **GET** /targetCollection/{tcId}/generation/targets/{generationId} | Status - Image Targets Creation
[**get_image_targets**](ImageTargetApi.md#get_image_targets) | **GET** /targetCollection/{tcId}/target | Get Image Targets
[**update_image_target**](ImageTargetApi.md#update_image_target) | **POST** /targetCollection/{tcId}/target/{targetId} | Update Image Target


# **create_image_targets**
> CreateImageTargetsResponse create_image_targets(x_version, x_token, content_type, tc_id)

Create Image Targets

Create a set of up to 10 new Targets in a Target Collection in your account. The task to create the listed Targets is scheduled. The response body contains the initial job status. \"Location\"-header is the url to the GET endpoint that returns current job status information. It is recommended to query this endpoint after \"estimatedLatency\" milliseconds, and poll it afterwards every 10 seconds in case job status is still not \"COMPLETED\". Once job status is \"COMPLETED\" each item holds a \"target\" attribute of the created target or an \"error\" attribute. 

### Example

```python
import time
import wikitude_studio_api_client
from wikitude_studio_api_client.api import image_target_api
from wikitude_studio_api_client.model.create_image_targets_body import CreateImageTargetsBody
from wikitude_studio_api_client.model.create_image_targets_response import CreateImageTargetsResponse
from pprint import pprint
# Defining the host is optional and defaults to https://api-eu.wikitude.com/cloudrecognition
# See configuration.py for a list of all supported configuration parameters.
configuration = wikitude_studio_api_client.Configuration(
    host = "https://api-eu.wikitude.com/cloudrecognition"
)


# Enter a context with an instance of the API client
with wikitude_studio_api_client.ApiClient() as api_client:
    # Create an instance of the API class
    api_instance = image_target_api.ImageTargetApi(api_client)
    x_version = "3" # str | The version of the API to be used. Must be set to 3.
    x_token = "X-Token_example" # str | Your Manager Token.
    content_type = "Content-Type_example" # str | The Content Type of the body. Must be set to application/json.
    tc_id = "tcId_example" # str | Unique identifier of the Image Target Collection.
    create_image_targets_body = [
        CreateImageTargetsBody(
            name="Some Target",
            image_url="https://wikitudeUrl.com/img.jpg",
            physical_height=42,
            metadata={},
        ),
    ] # [CreateImageTargetsBody] |  (optional)

    # example passing only required values which don't have defaults set
    try:
        # Create Image Targets
        api_response = api_instance.create_image_targets(x_version, x_token, content_type, tc_id)
        pprint(api_response)
    except wikitude_studio_api_client.ApiException as e:
        print("Exception when calling ImageTargetApi->create_image_targets: %s\n" % e)

    # example passing only required values which don't have defaults set
    # and optional values
    try:
        # Create Image Targets
        api_response = api_instance.create_image_targets(x_version, x_token, content_type, tc_id, create_image_targets_body=create_image_targets_body)
        pprint(api_response)
    except wikitude_studio_api_client.ApiException as e:
        print("Exception when calling ImageTargetApi->create_image_targets: %s\n" % e)
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **x_version** | **str**| The version of the API to be used. Must be set to 3. |
 **x_token** | **str**| Your Manager Token. |
 **content_type** | **str**| The Content Type of the body. Must be set to application/json. |
 **tc_id** | **str**| Unique identifier of the Image Target Collection. |
 **create_image_targets_body** | [**[CreateImageTargetsBody]**](CreateImageTargetsBody.md)|  | [optional]

### Return type

[**CreateImageTargetsResponse**](CreateImageTargetsResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**202** | The job of the Target creation task. |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID&lt;br/&gt; INVALID_PROPERTY&lt;br/&gt; DUPLICATE_TARGETIMAGE_USAGE  |  -  |
**401** | INVALID_TOKEN  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **delete_image_target**
> delete_image_target(x_version, x_token, tc_id, target_id)

Delete Image Target

Delete a particular Target from your account.

### Example

```python
import time
import wikitude_studio_api_client
from wikitude_studio_api_client.api import image_target_api
from pprint import pprint
# Defining the host is optional and defaults to https://api-eu.wikitude.com/cloudrecognition
# See configuration.py for a list of all supported configuration parameters.
configuration = wikitude_studio_api_client.Configuration(
    host = "https://api-eu.wikitude.com/cloudrecognition"
)


# Enter a context with an instance of the API client
with wikitude_studio_api_client.ApiClient() as api_client:
    # Create an instance of the API class
    api_instance = image_target_api.ImageTargetApi(api_client)
    x_version = "3" # str | The version of the API to be used. Must be set to 3.
    x_token = "X-Token_example" # str | Your Manager Token.
    tc_id = "tcId_example" # str | Unique identifier of the Image Target Collection.
    target_id = "targetId_example" # str | Unique identifier of the Image Target.

    # example passing only required values which don't have defaults set
    try:
        # Delete Image Target
        api_instance.delete_image_target(x_version, x_token, tc_id, target_id)
    except wikitude_studio_api_client.ApiException as e:
        print("Exception when calling ImageTargetApi->delete_image_target: %s\n" % e)
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **x_version** | **str**| The version of the API to be used. Must be set to 3. |
 **x_token** | **str**| Your Manager Token. |
 **tc_id** | **str**| Unique identifier of the Image Target Collection. |
 **target_id** | **str**| Unique identifier of the Image Target. |

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**204** | Successful operation - Empty response body. |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID  |  -  |
**401** | INVALID_TOKEN  |  -  |
**404** | TARGET_COLLECTION_NOT_FOUND&lt;br/&gt; TARGET_NOT_FOUND  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_image_target**
> ImageTargetResponse get_image_target(x_version, x_token, tc_id, target_id)

Get Image Target

Request a particular Image Target in a particular Target Collection.

### Example

```python
import time
import wikitude_studio_api_client
from wikitude_studio_api_client.api import image_target_api
from wikitude_studio_api_client.model.image_target_response import ImageTargetResponse
from pprint import pprint
# Defining the host is optional and defaults to https://api-eu.wikitude.com/cloudrecognition
# See configuration.py for a list of all supported configuration parameters.
configuration = wikitude_studio_api_client.Configuration(
    host = "https://api-eu.wikitude.com/cloudrecognition"
)


# Enter a context with an instance of the API client
with wikitude_studio_api_client.ApiClient() as api_client:
    # Create an instance of the API class
    api_instance = image_target_api.ImageTargetApi(api_client)
    x_version = "3" # str | The version of the API to be used. Must be set to 3.
    x_token = "X-Token_example" # str | Your Manager Token.
    tc_id = "tcId_example" # str | Unique identifier of the Image Target Collection.
    target_id = "targetId_example" # str | Unique identifier of the Image Target.

    # example passing only required values which don't have defaults set
    try:
        # Get Image Target
        api_response = api_instance.get_image_target(x_version, x_token, tc_id, target_id)
        pprint(api_response)
    except wikitude_studio_api_client.ApiException as e:
        print("Exception when calling ImageTargetApi->get_image_target: %s\n" % e)
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **x_version** | **str**| The version of the API to be used. Must be set to 3. |
 **x_token** | **str**| Your Manager Token. |
 **tc_id** | **str**| Unique identifier of the Image Target Collection. |
 **target_id** | **str**| Unique identifier of the Image Target. |

### Return type

[**ImageTargetResponse**](ImageTargetResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The particular requested Target. |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID  |  -  |
**401** | INVALID_TOKEN  |  -  |
**404** | TARGET_COLLECTION_NOT_FOUND&lt;br/&gt; TARGET_NOT_FOUND  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_image_target_status**
> CreateImageTargetsResponse get_image_target_status(x_version, x_token, tc_id, generation_id)

Status - Image Targets Creation

Retrieves information status about a particular scheduled targets creation.

### Example

```python
import time
import wikitude_studio_api_client
from wikitude_studio_api_client.api import image_target_api
from wikitude_studio_api_client.model.create_image_targets_response import CreateImageTargetsResponse
from pprint import pprint
# Defining the host is optional and defaults to https://api-eu.wikitude.com/cloudrecognition
# See configuration.py for a list of all supported configuration parameters.
configuration = wikitude_studio_api_client.Configuration(
    host = "https://api-eu.wikitude.com/cloudrecognition"
)


# Enter a context with an instance of the API client
with wikitude_studio_api_client.ApiClient() as api_client:
    # Create an instance of the API class
    api_instance = image_target_api.ImageTargetApi(api_client)
    x_version = "3" # str | The version of the API to be used. Must be set to 3.
    x_token = "X-Token_example" # str | Your Manager Token.
    tc_id = "tcId_example" # str | Unique identifier of the Image Target Collection.
    generation_id = "generationId_example" # str | Unique identifier of the asynchronous job created by a generation endpoint.

    # example passing only required values which don't have defaults set
    try:
        # Status - Image Targets Creation
        api_response = api_instance.get_image_target_status(x_version, x_token, tc_id, generation_id)
        pprint(api_response)
    except wikitude_studio_api_client.ApiException as e:
        print("Exception when calling ImageTargetApi->get_image_target_status: %s\n" % e)
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **x_version** | **str**| The version of the API to be used. Must be set to 3. |
 **x_token** | **str**| Your Manager Token. |
 **tc_id** | **str**| Unique identifier of the Image Target Collection. |
 **generation_id** | **str**| Unique identifier of the asynchronous job created by a generation endpoint. |

### Return type

[**CreateImageTargetsResponse**](CreateImageTargetsResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The requested job information, including \&quot;status\&quot;, \&quot;payload\&quot; attribute, \&quot;estimatedEnd\&quot;, \&quot;estimatedLatency\&quot; attributes. The \&quot;payload\&quot; contains a list of \&quot;creation-items\&quot;. Every item has an \&quot;input\&quot;-attribute that holds the JSON-Object used for creation (equals item at this index in post-body). Once status is \&quot;COMPLETED\&quot; every item also contains a \&quot;target\&quot;-attribute (same style as in successful single target creation) or an \&quot;error\&quot;-object (same as status 400 error JSON response in single target creation).  |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID  |  -  |
**401** | INVALID_TOKEN  |  -  |
**404** | GENERATION_NOT_FOUND  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_image_targets**
> [ImageTargetResponse] get_image_targets(x_version, x_token, tc_id)

Get Image Targets

Request all Image Targets in a Target Collection.

### Example

```python
import time
import wikitude_studio_api_client
from wikitude_studio_api_client.api import image_target_api
from wikitude_studio_api_client.model.image_target_response import ImageTargetResponse
from pprint import pprint
# Defining the host is optional and defaults to https://api-eu.wikitude.com/cloudrecognition
# See configuration.py for a list of all supported configuration parameters.
configuration = wikitude_studio_api_client.Configuration(
    host = "https://api-eu.wikitude.com/cloudrecognition"
)


# Enter a context with an instance of the API client
with wikitude_studio_api_client.ApiClient() as api_client:
    # Create an instance of the API class
    api_instance = image_target_api.ImageTargetApi(api_client)
    x_version = "3" # str | The version of the API to be used. Must be set to 3.
    x_token = "X-Token_example" # str | Your Manager Token.
    tc_id = "tcId_example" # str | Unique identifier of the Image Target Collection.
    sortby = "sortby_example" # str | Targets may be sorted by 'name', 'creDat', 'modDat', 'rating'. Default value: 'creDat' (optional)
    sortorder = "sortorder_example" # str | Targets may be sorted ascending ('asc') or descending ('desc'). Default value: 'desc' (optional)
    skip = 3.14 # float | Set 0 to start with first target, set e.g. to 2 to skip first 2 targets. Default value: 0 (optional)
    limit = 3.14 # float | Set to 0 for 'all targets' or use positive value to define max. amount of targets to return. Default value: 0 (optional)
    s = "s_example" # str | The search string to look for in target names. (optional)
    add_has_augmentations = True # bool | Add the hasAugmentations property. (optional)

    # example passing only required values which don't have defaults set
    try:
        # Get Image Targets
        api_response = api_instance.get_image_targets(x_version, x_token, tc_id)
        pprint(api_response)
    except wikitude_studio_api_client.ApiException as e:
        print("Exception when calling ImageTargetApi->get_image_targets: %s\n" % e)

    # example passing only required values which don't have defaults set
    # and optional values
    try:
        # Get Image Targets
        api_response = api_instance.get_image_targets(x_version, x_token, tc_id, sortby=sortby, sortorder=sortorder, skip=skip, limit=limit, s=s, add_has_augmentations=add_has_augmentations)
        pprint(api_response)
    except wikitude_studio_api_client.ApiException as e:
        print("Exception when calling ImageTargetApi->get_image_targets: %s\n" % e)
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **x_version** | **str**| The version of the API to be used. Must be set to 3. |
 **x_token** | **str**| Your Manager Token. |
 **tc_id** | **str**| Unique identifier of the Image Target Collection. |
 **sortby** | **str**| Targets may be sorted by &#39;name&#39;, &#39;creDat&#39;, &#39;modDat&#39;, &#39;rating&#39;. Default value: &#39;creDat&#39; | [optional]
 **sortorder** | **str**| Targets may be sorted ascending (&#39;asc&#39;) or descending (&#39;desc&#39;). Default value: &#39;desc&#39; | [optional]
 **skip** | **float**| Set 0 to start with first target, set e.g. to 2 to skip first 2 targets. Default value: 0 | [optional]
 **limit** | **float**| Set to 0 for &#39;all targets&#39; or use positive value to define max. amount of targets to return. Default value: 0 | [optional]
 **s** | **str**| The search string to look for in target names. | [optional]
 **add_has_augmentations** | **bool**| Add the hasAugmentations property. | [optional]

### Return type

[**[ImageTargetResponse]**](ImageTargetResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The Array of Targets in the Target Collection. |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID&lt;br/&gt; INVALID_QUERY_PARAMETER  |  -  |
**401** | INVALID_TOKEN  |  -  |
**404** | TARGET_COLLECTION_NOT_FOUND  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update_image_target**
> ImageTargetResponse update_image_target(x_version, x_token, content_type, tc_id, target_id, update_image_target_body)

Update Image Target

Updates properties of a particular Target in your account. Currently following properties are supported: physicalHeight, metadata. 

### Example

```python
import time
import wikitude_studio_api_client
from wikitude_studio_api_client.api import image_target_api
from wikitude_studio_api_client.model.image_target_response import ImageTargetResponse
from wikitude_studio_api_client.model.update_image_target_body import UpdateImageTargetBody
from pprint import pprint
# Defining the host is optional and defaults to https://api-eu.wikitude.com/cloudrecognition
# See configuration.py for a list of all supported configuration parameters.
configuration = wikitude_studio_api_client.Configuration(
    host = "https://api-eu.wikitude.com/cloudrecognition"
)


# Enter a context with an instance of the API client
with wikitude_studio_api_client.ApiClient() as api_client:
    # Create an instance of the API class
    api_instance = image_target_api.ImageTargetApi(api_client)
    x_version = "3" # str | The version of the API to be used. Must be set to 3.
    x_token = "X-Token_example" # str | Your Manager Token.
    content_type = "Content-Type_example" # str | The Content Type of the body. Must be set to application/json.
    tc_id = "tcId_example" # str | Unique identifier of the Image Target Collection.
    target_id = "targetId_example" # str | Unique identifier of the Image Target.
    update_image_target_body = UpdateImageTargetBody(
        physical_height=42,
        metadata={},
    ) # UpdateImageTargetBody | 

    # example passing only required values which don't have defaults set
    try:
        # Update Image Target
        api_response = api_instance.update_image_target(x_version, x_token, content_type, tc_id, target_id, update_image_target_body)
        pprint(api_response)
    except wikitude_studio_api_client.ApiException as e:
        print("Exception when calling ImageTargetApi->update_image_target: %s\n" % e)
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **x_version** | **str**| The version of the API to be used. Must be set to 3. |
 **x_token** | **str**| Your Manager Token. |
 **content_type** | **str**| The Content Type of the body. Must be set to application/json. |
 **tc_id** | **str**| Unique identifier of the Image Target Collection. |
 **target_id** | **str**| Unique identifier of the Image Target. |
 **update_image_target_body** | [**UpdateImageTargetBody**](UpdateImageTargetBody.md)|  |

### Return type

[**ImageTargetResponse**](ImageTargetResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The updated Image Target. |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID  |  -  |
**401** | INVALID_TOKEN  |  -  |
**404** | TARGET_COLLECTION_NOT_FOUND&lt;br/&gt; TARGET_NOT_FOUND  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

