# wikitude_studio_api_client.ImageTargetCollectionApi

All URIs are relative to *https://api-eu.wikitude.com/cloudrecognition*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create_image_target_collection**](ImageTargetCollectionApi.md#create_image_target_collection) | **POST** /targetCollection | Create Image Target Collection
[**delete_image_target_collection**](ImageTargetCollectionApi.md#delete_image_target_collection) | **DELETE** /targetCollection/{tcId} | Delete Image Target Collection
[**generate_cloud_archive**](ImageTargetCollectionApi.md#generate_cloud_archive) | **POST** /targetCollection/{tcId}/generation/cloudarchive | Generate Cloud Archive
[**generate_wtc**](ImageTargetCollectionApi.md#generate_wtc) | **POST** /targetCollection/{tcId}/generation/wtc | Generate WTC
[**get_cloud_archive_status**](ImageTargetCollectionApi.md#get_cloud_archive_status) | **GET** /targetCollection/{tcId}/generation/cloudarchive/{generationId} | Status - Generate Cloud Archive
[**get_image_target_collection**](ImageTargetCollectionApi.md#get_image_target_collection) | **GET** /targetCollection/{tcId} | Get Image Target Collection
[**get_image_target_collections**](ImageTargetCollectionApi.md#get_image_target_collections) | **GET** /targetCollection | Get all Image Target Collections
[**get_similarity_check_status**](ImageTargetCollectionApi.md#get_similarity_check_status) | **GET** /targetCollection/{tcId}/similarity/{generationId} | Status - Similarity Check
[**get_wtc_status**](ImageTargetCollectionApi.md#get_wtc_status) | **GET** /targetCollection/{tcId}/generation/wtc/{generationId} | Status - Generate WTC
[**similarity_check**](ImageTargetCollectionApi.md#similarity_check) | **POST** /targetCollection/{tcId}/similarity | Similarity Check
[**update_image_target_collection**](ImageTargetCollectionApi.md#update_image_target_collection) | **POST** /targetCollection/{tcId} | Update Image Target Collection


# **create_image_target_collection**
> ImageTargetCollectionResponse create_image_target_collection(x_version, x_token, content_type, create_image_target_collection_body)

Create Image Target Collection

Create a new target collection in your account.

### Example

```python
import time
import wikitude_studio_api_client
from wikitude_studio_api_client.api import image_target_collection_api
from wikitude_studio_api_client.model.image_target_collection_response import ImageTargetCollectionResponse
from wikitude_studio_api_client.model.create_image_target_collection_body import CreateImageTargetCollectionBody
from pprint import pprint
# Defining the host is optional and defaults to https://api-eu.wikitude.com/cloudrecognition
# See configuration.py for a list of all supported configuration parameters.
configuration = wikitude_studio_api_client.Configuration(
    host = "https://api-eu.wikitude.com/cloudrecognition"
)


# Enter a context with an instance of the API client
with wikitude_studio_api_client.ApiClient() as api_client:
    # Create an instance of the API class
    api_instance = image_target_collection_api.ImageTargetCollectionApi(api_client)
    x_version = "3" # str | The version of the API to be used. Must be set to 3.
    x_token = "X-Token_example" # str | Your Manager Token.
    content_type = "Content-Type_example" # str | The Content Type of the body. Must be set to application/json.
    create_image_target_collection_body = CreateImageTargetCollectionBody(
        name="Some Target Collection",
        cloud_archive=CreateImageTargetCollectionBodyCloudArchive(
            enabled=True,
        ),
        metadata={},
    ) # CreateImageTargetCollectionBody | 

    # example passing only required values which don't have defaults set
    try:
        # Create Image Target Collection
        api_response = api_instance.create_image_target_collection(x_version, x_token, content_type, create_image_target_collection_body)
        pprint(api_response)
    except wikitude_studio_api_client.ApiException as e:
        print("Exception when calling ImageTargetCollectionApi->create_image_target_collection: %s\n" % e)
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **x_version** | **str**| The version of the API to be used. Must be set to 3. |
 **x_token** | **str**| Your Manager Token. |
 **content_type** | **str**| The Content Type of the body. Must be set to application/json. |
 **create_image_target_collection_body** | [**CreateImageTargetCollectionBody**](CreateImageTargetCollectionBody.md)|  |

### Return type

[**ImageTargetCollectionResponse**](ImageTargetCollectionResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The newly created TargetCollection. |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID&lt;br/&gt; INVALID_PROPERTY&lt;br/&gt; BODY_CONTENT_TOO_LARGE  |  -  |
**401** | INVALID_TOKEN  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **delete_image_target_collection**
> delete_image_target_collection(x_version, x_token, tc_id)

Delete Image Target Collection

Delete a particular target collection from your account.

### Example

```python
import time
import wikitude_studio_api_client
from wikitude_studio_api_client.api import image_target_collection_api
from pprint import pprint
# Defining the host is optional and defaults to https://api-eu.wikitude.com/cloudrecognition
# See configuration.py for a list of all supported configuration parameters.
configuration = wikitude_studio_api_client.Configuration(
    host = "https://api-eu.wikitude.com/cloudrecognition"
)


# Enter a context with an instance of the API client
with wikitude_studio_api_client.ApiClient() as api_client:
    # Create an instance of the API class
    api_instance = image_target_collection_api.ImageTargetCollectionApi(api_client)
    x_version = "3" # str | The version of the API to be used. Must be set to 3.
    x_token = "X-Token_example" # str | Your Manager Token.
    tc_id = "tcId_example" # str | Unique identifier of the Image Target Collection.

    # example passing only required values which don't have defaults set
    try:
        # Delete Image Target Collection
        api_instance.delete_image_target_collection(x_version, x_token, tc_id)
    except wikitude_studio_api_client.ApiException as e:
        print("Exception when calling ImageTargetCollectionApi->delete_image_target_collection: %s\n" % e)
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **x_version** | **str**| The version of the API to be used. Must be set to 3. |
 **x_token** | **str**| Your Manager Token. |
 **tc_id** | **str**| Unique identifier of the Image Target Collection. |

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**204** | Successful operation - Empty response body. |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID  |  -  |
**401** | INVALID_TOKEN  |  -  |
**404** | TARGET_COLLECTION_NOT_FOUND  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **generate_cloud_archive**
> CloudArchiveGenerationResponse generate_cloud_archive(x_version, x_token, tc_id)

Generate Cloud Archive

DEPRECATED - Generate a Cloud Archive from an existing Target Collection. The call is asynchronous and contains a path in the response header (Location) from which the status of the generation can be requested (see Status - Generate Cloud Archive). As of release 4.0.0 this endpoint will return error TARGET_COLLECTION_IS_UP_TO_DATE with status code 412, since the archive will be generated automatically in the background in the future. This endpoint is marked as \"deprecated\" since the behaviour will slightly change. However, this endpoint will still exist in version 3. 

### Example

```python
import time
import wikitude_studio_api_client
from wikitude_studio_api_client.api import image_target_collection_api
from wikitude_studio_api_client.model.cloud_archive_generation_response import CloudArchiveGenerationResponse
from pprint import pprint
# Defining the host is optional and defaults to https://api-eu.wikitude.com/cloudrecognition
# See configuration.py for a list of all supported configuration parameters.
configuration = wikitude_studio_api_client.Configuration(
    host = "https://api-eu.wikitude.com/cloudrecognition"
)


# Enter a context with an instance of the API client
with wikitude_studio_api_client.ApiClient() as api_client:
    # Create an instance of the API class
    api_instance = image_target_collection_api.ImageTargetCollectionApi(api_client)
    x_version = "3" # str | The version of the API to be used. Must be set to 3.
    x_token = "X-Token_example" # str | Your Manager Token.
    tc_id = "tcId_example" # str | Unique identifier of the Image Target Collection.

    # example passing only required values which don't have defaults set
    try:
        # Generate Cloud Archive
        api_response = api_instance.generate_cloud_archive(x_version, x_token, tc_id)
        pprint(api_response)
    except wikitude_studio_api_client.ApiException as e:
        print("Exception when calling ImageTargetCollectionApi->generate_cloud_archive: %s\n" % e)
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **x_version** | **str**| The version of the API to be used. Must be set to 3. |
 **x_token** | **str**| Your Manager Token. |
 **tc_id** | **str**| Unique identifier of the Image Target Collection. |

### Return type

[**CloudArchiveGenerationResponse**](CloudArchiveGenerationResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**202** | successful execution |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID&lt;br/&gt; BODY_CONTENT_TOO_LARGE  |  -  |
**401** | INVALID_TOKEN  |  -  |
**404** | TARGET_COLLECTION_NOT_FOUND  |  -  |
**412** | TARGET_COLLECTION_IS_UP_TO_DATE&lt;br/&gt; TARGET_COLLECTION_GENERATION_PENDING&lt;br/&gt; TARGET_COLLECTION_IS_EMPTY  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **generate_wtc**
> GenerateWTCStatusResponse generate_wtc(x_version, x_token, content_type, tc_id, generate_wtc_body)

Generate WTC

Generates a WTC file out of an existing Target Collection with up to 1000 targets. The call is asynchronous and contains a path in the response header (Location) from which the status of the generation can be requested (see Status - Generate WTC). 

### Example

```python
import time
import wikitude_studio_api_client
from wikitude_studio_api_client.api import image_target_collection_api
from wikitude_studio_api_client.model.generate_wtc_status_response import GenerateWTCStatusResponse
from wikitude_studio_api_client.model.generate_wtc_body import GenerateWTCBody
from pprint import pprint
# Defining the host is optional and defaults to https://api-eu.wikitude.com/cloudrecognition
# See configuration.py for a list of all supported configuration parameters.
configuration = wikitude_studio_api_client.Configuration(
    host = "https://api-eu.wikitude.com/cloudrecognition"
)


# Enter a context with an instance of the API client
with wikitude_studio_api_client.ApiClient() as api_client:
    # Create an instance of the API class
    api_instance = image_target_collection_api.ImageTargetCollectionApi(api_client)
    x_version = "3" # str | The version of the API to be used. Must be set to 3.
    x_token = "X-Token_example" # str | Your Manager Token.
    content_type = "Content-Type_example" # str | The Content Type of the body. Must be set to application/json.
    tc_id = "tcId_example" # str | Unique identifier of the Image Target Collection.
    generate_wtc_body = GenerateWTCBody(
        sdk_version="8.5",
        e_mail="noreply@wikitude.com",
    ) # GenerateWTCBody | 

    # example passing only required values which don't have defaults set
    try:
        # Generate WTC
        api_response = api_instance.generate_wtc(x_version, x_token, content_type, tc_id, generate_wtc_body)
        pprint(api_response)
    except wikitude_studio_api_client.ApiException as e:
        print("Exception when calling ImageTargetCollectionApi->generate_wtc: %s\n" % e)
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **x_version** | **str**| The version of the API to be used. Must be set to 3. |
 **x_token** | **str**| Your Manager Token. |
 **content_type** | **str**| The Content Type of the body. Must be set to application/json. |
 **tc_id** | **str**| Unique identifier of the Image Target Collection. |
 **generate_wtc_body** | [**GenerateWTCBody**](GenerateWTCBody.md)|  |

### Return type

[**GenerateWTCStatusResponse**](GenerateWTCStatusResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**202** | The particular requested generation status. |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID  |  -  |
**401** | INVALID_TOKEN  |  -  |
**404** | TARGET_COLLECTION_NOT_FOUND  |  -  |
**412** | TARGET_COLLECTION_IS_EMPTY&lt;br/&gt; TARGET_COLLECTION_TOO_LARGE_FOR_WTC  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_cloud_archive_status**
> CloudArchiveGenerationResponse get_cloud_archive_status(x_version, x_token, tc_id, generation_id)

Status - Generate Cloud Archive

Retrieves information status about a particular scheduled cloud archive generation.

### Example

```python
import time
import wikitude_studio_api_client
from wikitude_studio_api_client.api import image_target_collection_api
from wikitude_studio_api_client.model.cloud_archive_generation_response import CloudArchiveGenerationResponse
from pprint import pprint
# Defining the host is optional and defaults to https://api-eu.wikitude.com/cloudrecognition
# See configuration.py for a list of all supported configuration parameters.
configuration = wikitude_studio_api_client.Configuration(
    host = "https://api-eu.wikitude.com/cloudrecognition"
)


# Enter a context with an instance of the API client
with wikitude_studio_api_client.ApiClient() as api_client:
    # Create an instance of the API class
    api_instance = image_target_collection_api.ImageTargetCollectionApi(api_client)
    x_version = "3" # str | The version of the API to be used. Must be set to 3.
    x_token = "X-Token_example" # str | Your Manager Token.
    tc_id = "tcId_example" # str | Unique identifier of the Image Target Collection.
    generation_id = "generationId_example" # str | Unique identifier of the asynchronous job created by a generation endpoint.

    # example passing only required values which don't have defaults set
    try:
        # Status - Generate Cloud Archive
        api_response = api_instance.get_cloud_archive_status(x_version, x_token, tc_id, generation_id)
        pprint(api_response)
    except wikitude_studio_api_client.ApiException as e:
        print("Exception when calling ImageTargetCollectionApi->get_cloud_archive_status: %s\n" % e)
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **x_version** | **str**| The version of the API to be used. Must be set to 3. |
 **x_token** | **str**| Your Manager Token. |
 **tc_id** | **str**| Unique identifier of the Image Target Collection. |
 **generation_id** | **str**| Unique identifier of the asynchronous job created by a generation endpoint. |

### Return type

[**CloudArchiveGenerationResponse**](CloudArchiveGenerationResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The particular requested generation job details. In case JSON attribute status is \&quot;COMPLETED\&quot; the generation finished.  |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID  |  -  |
**401** | INVALID_TOKEN  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_image_target_collection**
> ImageTargetCollectionResponse get_image_target_collection(x_version, x_token, tc_id)

Get Image Target Collection

Request a particular target collection from your account.

### Example

```python
import time
import wikitude_studio_api_client
from wikitude_studio_api_client.api import image_target_collection_api
from wikitude_studio_api_client.model.image_target_collection_response import ImageTargetCollectionResponse
from pprint import pprint
# Defining the host is optional and defaults to https://api-eu.wikitude.com/cloudrecognition
# See configuration.py for a list of all supported configuration parameters.
configuration = wikitude_studio_api_client.Configuration(
    host = "https://api-eu.wikitude.com/cloudrecognition"
)


# Enter a context with an instance of the API client
with wikitude_studio_api_client.ApiClient() as api_client:
    # Create an instance of the API class
    api_instance = image_target_collection_api.ImageTargetCollectionApi(api_client)
    x_version = "3" # str | The version of the API to be used. Must be set to 3.
    x_token = "X-Token_example" # str | Your Manager Token.
    tc_id = "tcId_example" # str | Unique identifier of the Image Target Collection.

    # example passing only required values which don't have defaults set
    try:
        # Get Image Target Collection
        api_response = api_instance.get_image_target_collection(x_version, x_token, tc_id)
        pprint(api_response)
    except wikitude_studio_api_client.ApiException as e:
        print("Exception when calling ImageTargetCollectionApi->get_image_target_collection: %s\n" % e)
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **x_version** | **str**| The version of the API to be used. Must be set to 3. |
 **x_token** | **str**| Your Manager Token. |
 **tc_id** | **str**| Unique identifier of the Image Target Collection. |

### Return type

[**ImageTargetCollectionResponse**](ImageTargetCollectionResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The particular requested TargetCollection. |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID  |  -  |
**401** | INVALID_TOKEN  |  -  |
**404** | TARGET_COLLECTION_NOT_FOUND  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_image_target_collections**
> [ImageTargetCollectionResponse] get_image_target_collections(x_version, x_token)

Get all Image Target Collections

Request all target collections from your account.

### Example

```python
import time
import wikitude_studio_api_client
from wikitude_studio_api_client.api import image_target_collection_api
from wikitude_studio_api_client.model.image_target_collection_response import ImageTargetCollectionResponse
from pprint import pprint
# Defining the host is optional and defaults to https://api-eu.wikitude.com/cloudrecognition
# See configuration.py for a list of all supported configuration parameters.
configuration = wikitude_studio_api_client.Configuration(
    host = "https://api-eu.wikitude.com/cloudrecognition"
)


# Enter a context with an instance of the API client
with wikitude_studio_api_client.ApiClient() as api_client:
    # Create an instance of the API class
    api_instance = image_target_collection_api.ImageTargetCollectionApi(api_client)
    x_version = "3" # str | The version of the API to be used. Must be set to 3.
    x_token = "X-Token_example" # str | Your Manager Token.
    skip = 1 # int | Set 0 to start with first entry, set e.g. to 2 to skip first 2 entries. Default value: 0 (optional)
    limit = 1 # int | Use positive value to define the amount of entries to return [1, 1000] per page. Default value: 1000 (optional)

    # example passing only required values which don't have defaults set
    try:
        # Get all Image Target Collections
        api_response = api_instance.get_image_target_collections(x_version, x_token)
        pprint(api_response)
    except wikitude_studio_api_client.ApiException as e:
        print("Exception when calling ImageTargetCollectionApi->get_image_target_collections: %s\n" % e)

    # example passing only required values which don't have defaults set
    # and optional values
    try:
        # Get all Image Target Collections
        api_response = api_instance.get_image_target_collections(x_version, x_token, skip=skip, limit=limit)
        pprint(api_response)
    except wikitude_studio_api_client.ApiException as e:
        print("Exception when calling ImageTargetCollectionApi->get_image_target_collections: %s\n" % e)
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **x_version** | **str**| The version of the API to be used. Must be set to 3. |
 **x_token** | **str**| Your Manager Token. |
 **skip** | **int**| Set 0 to start with first entry, set e.g. to 2 to skip first 2 entries. Default value: 0 | [optional]
 **limit** | **int**| Use positive value to define the amount of entries to return [1, 1000] per page. Default value: 1000 | [optional]

### Return type

[**[ImageTargetCollectionResponse]**](ImageTargetCollectionResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The Array of Image Target Collections in your account. |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID&lt;br/&gt; INVALID_QUERY_PARAMETER  |  -  |
**401** | INVALID_TOKEN  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_similarity_check_status**
> SimilarityCheckStatusResponse get_similarity_check_status(x_version, x_token, tc_id, generation_id)

Status - Similarity Check

Retrieves information status of a particular scheduled \"Similarity Check\".

### Example

```python
import time
import wikitude_studio_api_client
from wikitude_studio_api_client.api import image_target_collection_api
from wikitude_studio_api_client.model.similarity_check_status_response import SimilarityCheckStatusResponse
from pprint import pprint
# Defining the host is optional and defaults to https://api-eu.wikitude.com/cloudrecognition
# See configuration.py for a list of all supported configuration parameters.
configuration = wikitude_studio_api_client.Configuration(
    host = "https://api-eu.wikitude.com/cloudrecognition"
)


# Enter a context with an instance of the API client
with wikitude_studio_api_client.ApiClient() as api_client:
    # Create an instance of the API class
    api_instance = image_target_collection_api.ImageTargetCollectionApi(api_client)
    x_version = "3" # str | The version of the API to be used. Must be set to 3.
    x_token = "X-Token_example" # str | Your Manager Token.
    tc_id = "tcId_example" # str | Unique identifier of the Image Target Collection.
    generation_id = "generationId_example" # str | Unique identifier of the asynchronous job created by a generation endpoint.

    # example passing only required values which don't have defaults set
    try:
        # Status - Similarity Check
        api_response = api_instance.get_similarity_check_status(x_version, x_token, tc_id, generation_id)
        pprint(api_response)
    except wikitude_studio_api_client.ApiException as e:
        print("Exception when calling ImageTargetCollectionApi->get_similarity_check_status: %s\n" % e)
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **x_version** | **str**| The version of the API to be used. Must be set to 3. |
 **x_token** | **str**| Your Manager Token. |
 **tc_id** | **str**| Unique identifier of the Image Target Collection. |
 **generation_id** | **str**| Unique identifier of the asynchronous job created by a generation endpoint. |

### Return type

[**SimilarityCheckStatusResponse**](SimilarityCheckStatusResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The requested job information as JSON with \&quot;id\&quot;, \&quot;status\&quot;, \&quot;inputParams\&quot;, \&quot;created\&quot; and \&quot;estimatedLatency\&quot; attributes. In case status is \&quot;FAILED\&quot; and \&quot;error\&quot; attribute is added to provide more details. Once status is \&quot;COMPLETED\&quot; a \&quot;payload\&quot; attribute holds the list of images where each of them has an additional \&quot;candidates\&quot;-attribute in case of success or an \&quot;error\&quot;-object in case an unexpected error occurred. A candidate has a \&quot;targetName\&quot; and a \&quot;score\&quot; value between 0 and 1, where a large score means a high similarity. Every job has an \&quot;input\&quot;-attribute holding the JSON-Object used for creation (same information as used in POST-body plus \&quot;tcId\&quot;). Life cycle of a job is SCHEDULED -&gt; RUNNING -&gt; COMPLETED/FAILED.  |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID  |  -  |
**401** | INVALID_TOKEN  |  -  |
**404** | GENERATION_NOT_FOUND  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_wtc_status**
> GenerateWTCStatusResponse get_wtc_status(x_version, x_token, tc_id, generation_id)

Status - Generate WTC

Retrieves information status about a particular scheduled WTC file generation. Once the status is completed, the WTC information can be retrieved from the Target Collection (see Get Target Collection). 

### Example

```python
import time
import wikitude_studio_api_client
from wikitude_studio_api_client.api import image_target_collection_api
from wikitude_studio_api_client.model.generate_wtc_status_response import GenerateWTCStatusResponse
from pprint import pprint
# Defining the host is optional and defaults to https://api-eu.wikitude.com/cloudrecognition
# See configuration.py for a list of all supported configuration parameters.
configuration = wikitude_studio_api_client.Configuration(
    host = "https://api-eu.wikitude.com/cloudrecognition"
)


# Enter a context with an instance of the API client
with wikitude_studio_api_client.ApiClient() as api_client:
    # Create an instance of the API class
    api_instance = image_target_collection_api.ImageTargetCollectionApi(api_client)
    x_version = "3" # str | The version of the API to be used. Must be set to 3.
    x_token = "X-Token_example" # str | Your Manager Token.
    tc_id = "tcId_example" # str | Unique identifier of the Image Target Collection.
    generation_id = "generationId_example" # str | Unique identifier of the asynchronous job created by a generation endpoint.

    # example passing only required values which don't have defaults set
    try:
        # Status - Generate WTC
        api_response = api_instance.get_wtc_status(x_version, x_token, tc_id, generation_id)
        pprint(api_response)
    except wikitude_studio_api_client.ApiException as e:
        print("Exception when calling ImageTargetCollectionApi->get_wtc_status: %s\n" % e)
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **x_version** | **str**| The version of the API to be used. Must be set to 3. |
 **x_token** | **str**| Your Manager Token. |
 **tc_id** | **str**| Unique identifier of the Image Target Collection. |
 **generation_id** | **str**| Unique identifier of the asynchronous job created by a generation endpoint. |

### Return type

[**GenerateWTCStatusResponse**](GenerateWTCStatusResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The particular requested generation status. |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID  |  -  |
**401** | INVALID_TOKEN  |  -  |
**404** | GENERATION_NOT_FOUND  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **similarity_check**
> SimilarityCheckResponse similarity_check(x_version, x_token, content_type, tc_id, similarity_check_body)

Similarity Check

Pass up to 10 items pointing to PNG or JPEG images hosted via https in the body. In order to find out whether an image is similar to an existing Target in terms of recognition and tracking behaviour a check is performed per passed image item. The Target Collection must be published and have an active Cloud Archive in place. Up to 5 (default: 1) so called \"candidates\" with a similarity \"score\" are returned per image. Image must be hosted via https and be of type PNG or JPEG. Use \"maxCandidates\" to define the maximum amount of candidates to return for an image. Response header value \"Location\" directly points to the right \"Status - Similarity Check\" endpoint. Best practice is to trigger \"Similarity Check\", wait for \"estimatedLatency\" milliseconds and poll \"Status - Similarity Check\" endpoint every 5 seconds until its \"status\" is \"COMPLETED\". 

### Example

```python
import time
import wikitude_studio_api_client
from wikitude_studio_api_client.api import image_target_collection_api
from wikitude_studio_api_client.model.similarity_check_body import SimilarityCheckBody
from wikitude_studio_api_client.model.similarity_check_response import SimilarityCheckResponse
from pprint import pprint
# Defining the host is optional and defaults to https://api-eu.wikitude.com/cloudrecognition
# See configuration.py for a list of all supported configuration parameters.
configuration = wikitude_studio_api_client.Configuration(
    host = "https://api-eu.wikitude.com/cloudrecognition"
)


# Enter a context with an instance of the API client
with wikitude_studio_api_client.ApiClient() as api_client:
    # Create an instance of the API class
    api_instance = image_target_collection_api.ImageTargetCollectionApi(api_client)
    x_version = "3" # str | The version of the API to be used. Must be set to 3.
    x_token = "X-Token_example" # str | Your Manager Token.
    content_type = "Content-Type_example" # str | The Content Type of the body. Must be set to application/json.
    tc_id = "tcId_example" # str | Unique identifier of the Image Target Collection.
    similarity_check_body = SimilarityCheckBody(
        images=[
            SimilarityCheckBodyImages(
                image_url="https://wikitudeUrl.com/img.jpg",
                max_candidates=5,
            ),
        ],
    ) # SimilarityCheckBody | 

    # example passing only required values which don't have defaults set
    try:
        # Similarity Check
        api_response = api_instance.similarity_check(x_version, x_token, content_type, tc_id, similarity_check_body)
        pprint(api_response)
    except wikitude_studio_api_client.ApiException as e:
        print("Exception when calling ImageTargetCollectionApi->similarity_check: %s\n" % e)
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **x_version** | **str**| The version of the API to be used. Must be set to 3. |
 **x_token** | **str**| Your Manager Token. |
 **content_type** | **str**| The Content Type of the body. Must be set to application/json. |
 **tc_id** | **str**| Unique identifier of the Image Target Collection. |
 **similarity_check_body** | [**SimilarityCheckBody**](SimilarityCheckBody.md)|  |

### Return type

[**SimilarityCheckResponse**](SimilarityCheckResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**202** | Response Code with header value \&quot;Location\&quot; which points to the \&quot;Status - Similarity Check\&quot; endpoint. Body holds async job information. A JSON Object with an \&quot;id\&quot; (for \&quot;Status - Similarity Check\&quot; GET endpoint), \&quot;inputParams\&quot; (JSON Object holding the \&quot;images\&quot; as a list and the tcId), \&quot;status\&quot; (\&quot;SCHEDULED\&quot;, \&quot;COMPLETED\&quot;, \&quot;FAILED\&quot;), \&quot;estimatedLatency\&quot; and \&quot;created\&quot; timestamps.  |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID&lt;br/&gt; INVALID_QUERY_PARAMETER  |  -  |
**401** | INVALID_TOKEN  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update_image_target_collection**
> ImageTargetCollectionResponse update_image_target_collection(x_version, x_token, content_type, tc_id, update_image_target_collection_body)

Update Image Target Collection

Update a target collection from your account.

### Example

```python
import time
import wikitude_studio_api_client
from wikitude_studio_api_client.api import image_target_collection_api
from wikitude_studio_api_client.model.image_target_collection_response import ImageTargetCollectionResponse
from wikitude_studio_api_client.model.update_image_target_collection_body import UpdateImageTargetCollectionBody
from pprint import pprint
# Defining the host is optional and defaults to https://api-eu.wikitude.com/cloudrecognition
# See configuration.py for a list of all supported configuration parameters.
configuration = wikitude_studio_api_client.Configuration(
    host = "https://api-eu.wikitude.com/cloudrecognition"
)


# Enter a context with an instance of the API client
with wikitude_studio_api_client.ApiClient() as api_client:
    # Create an instance of the API class
    api_instance = image_target_collection_api.ImageTargetCollectionApi(api_client)
    x_version = "3" # str | The version of the API to be used. Must be set to 3.
    x_token = "X-Token_example" # str | Your Manager Token.
    content_type = "Content-Type_example" # str | The Content Type of the body. Must be set to application/json.
    tc_id = "tcId_example" # str | Unique identifier of the Image Target Collection.
    update_image_target_collection_body = UpdateImageTargetCollectionBody(
        name="Some Target Collection",
        cloud_archive=CreateImageTargetCollectionBodyCloudArchive(
            enabled=True,
        ),
        metadata={},
    ) # UpdateImageTargetCollectionBody | 

    # example passing only required values which don't have defaults set
    try:
        # Update Image Target Collection
        api_response = api_instance.update_image_target_collection(x_version, x_token, content_type, tc_id, update_image_target_collection_body)
        pprint(api_response)
    except wikitude_studio_api_client.ApiException as e:
        print("Exception when calling ImageTargetCollectionApi->update_image_target_collection: %s\n" % e)
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **x_version** | **str**| The version of the API to be used. Must be set to 3. |
 **x_token** | **str**| Your Manager Token. |
 **content_type** | **str**| The Content Type of the body. Must be set to application/json. |
 **tc_id** | **str**| Unique identifier of the Image Target Collection. |
 **update_image_target_collection_body** | [**UpdateImageTargetCollectionBody**](UpdateImageTargetCollectionBody.md)|  |

### Return type

[**ImageTargetCollectionResponse**](ImageTargetCollectionResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The updated Image Target Collection. |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID&lt;br/&gt; BODY_CONTENT_TOO_LARGE  |  -  |
**401** | INVALID_TOKEN  |  -  |
**404** | TARGET_COLLECTION_NOT_FOUND  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

