# wikitude_studio_api_client.ObjectTargetApi

All URIs are relative to *https://api-eu.wikitude.com/cloudrecognition*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create_object_target_from_images**](ObjectTargetApi.md#create_object_target_from_images) | **POST** /objectTargetCollection/{tcId}/target/images | Create Object Target from Images
[**create_object_target_from_wto**](ObjectTargetApi.md#create_object_target_from_wto) | **POST** /objectTargetCollection/{tcId}/target/wto | Create Object Target from WTO
[**delete_object_target**](ObjectTargetApi.md#delete_object_target) | **DELETE** /objectTargetCollection/{tcId}/target/{targetId} | Delete Object Target
[**extend_object_target**](ObjectTargetApi.md#extend_object_target) | **PUT** /objectTargetCollection/{tcId}/target/{targetId} | Extend Object Target
[**get_object_target**](ObjectTargetApi.md#get_object_target) | **GET** /objectTargetCollection/{tcId}/target/{targetId} | Get Object Target
[**get_object_target_status**](ObjectTargetApi.md#get_object_target_status) | **GET** /objectTargetCollection/{tcId}/generation/targets/{generationId} | Status - Object Target Generation Information
[**get_object_targets**](ObjectTargetApi.md#get_object_targets) | **GET** /objectTargetCollection/{tcId}/target | Get Object Targets
[**rename_object_target**](ObjectTargetApi.md#rename_object_target) | **PUT** /objectTargetCollection/{tcId}/target/{targetId}/name | Rename Object Target


# **create_object_target_from_images**
> ObjectTargetJobResponse create_object_target_from_images(x_version, x_token, content_type, tc_id, create_object_target_images_body)

Create Object Target from Images

Create a new Object Target in an Object Target Collection from at least two Image files.

### Example

```python
import time
import wikitude_studio_api_client
from wikitude_studio_api_client.api import object_target_api
from wikitude_studio_api_client.model.create_object_target_images_body import CreateObjectTargetImagesBody
from wikitude_studio_api_client.model.object_target_job_response import ObjectTargetJobResponse
from pprint import pprint
# Defining the host is optional and defaults to https://api-eu.wikitude.com/cloudrecognition
# See configuration.py for a list of all supported configuration parameters.
configuration = wikitude_studio_api_client.Configuration(
    host = "https://api-eu.wikitude.com/cloudrecognition"
)


# Enter a context with an instance of the API client
with wikitude_studio_api_client.ApiClient() as api_client:
    # Create an instance of the API class
    api_instance = object_target_api.ObjectTargetApi(api_client)
    x_version = "3" # str | The version of the API to be used. Must be set to 3.
    x_token = "X-Token_example" # str | Your Manager Token.
    content_type = "Content-Type_example" # str | The Content Type of the body. Must be set to application/json.
    tc_id = "tcId_example" # str | Unique identifier of the Object Target Collection.
    create_object_target_images_body = CreateObjectTargetImagesBody(
        name="Some Target",
        resource=CreateObjectTargetImagesBodyResource(
            uri=[
                "https://wikitudeUrl.com/objectImage.jpg",
            ],
            fov=60,
        ),
        metadata={},
    ) # CreateObjectTargetImagesBody | 

    # example passing only required values which don't have defaults set
    try:
        # Create Object Target from Images
        api_response = api_instance.create_object_target_from_images(x_version, x_token, content_type, tc_id, create_object_target_images_body)
        pprint(api_response)
    except wikitude_studio_api_client.ApiException as e:
        print("Exception when calling ObjectTargetApi->create_object_target_from_images: %s\n" % e)
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **x_version** | **str**| The version of the API to be used. Must be set to 3. |
 **x_token** | **str**| Your Manager Token. |
 **content_type** | **str**| The Content Type of the body. Must be set to application/json. |
 **tc_id** | **str**| Unique identifier of the Object Target Collection. |
 **create_object_target_images_body** | [**CreateObjectTargetImagesBody**](CreateObjectTargetImagesBody.md)|  |

### Return type

[**ObjectTargetJobResponse**](ObjectTargetJobResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The asynchronous job information. |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID  |  -  |
**401** | INVALID_TOKEN  |  -  |
**404** | OBJECT_TARGET_COLLECTION_NOT_FOUND  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **create_object_target_from_wto**
> ObjectTargetJobResponse create_object_target_from_wto(x_version, x_token, content_type, tc_id, create_object_target_wto_body)

Create Object Target from WTO

Create a new Object Target in an Object Target Collection from a WTO file.

### Example

```python
import time
import wikitude_studio_api_client
from wikitude_studio_api_client.api import object_target_api
from wikitude_studio_api_client.model.create_object_target_wto_body import CreateObjectTargetWTOBody
from wikitude_studio_api_client.model.object_target_job_response import ObjectTargetJobResponse
from pprint import pprint
# Defining the host is optional and defaults to https://api-eu.wikitude.com/cloudrecognition
# See configuration.py for a list of all supported configuration parameters.
configuration = wikitude_studio_api_client.Configuration(
    host = "https://api-eu.wikitude.com/cloudrecognition"
)


# Enter a context with an instance of the API client
with wikitude_studio_api_client.ApiClient() as api_client:
    # Create an instance of the API class
    api_instance = object_target_api.ObjectTargetApi(api_client)
    x_version = "3" # str | The version of the API to be used. Must be set to 3.
    x_token = "X-Token_example" # str | Your Manager Token.
    content_type = "Content-Type_example" # str | The Content Type of the body. Must be set to application/json.
    tc_id = "tcId_example" # str | Unique identifier of the Object Target Collection.
    create_object_target_wto_body = CreateObjectTargetWTOBody(
        type="wto",
        resource=CreateObjectTargetWTOBodyResource(
            uri="https://wikitudeUrl.com/target.wto",
        ),
    ) # CreateObjectTargetWTOBody | 

    # example passing only required values which don't have defaults set
    try:
        # Create Object Target from WTO
        api_response = api_instance.create_object_target_from_wto(x_version, x_token, content_type, tc_id, create_object_target_wto_body)
        pprint(api_response)
    except wikitude_studio_api_client.ApiException as e:
        print("Exception when calling ObjectTargetApi->create_object_target_from_wto: %s\n" % e)
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **x_version** | **str**| The version of the API to be used. Must be set to 3. |
 **x_token** | **str**| Your Manager Token. |
 **content_type** | **str**| The Content Type of the body. Must be set to application/json. |
 **tc_id** | **str**| Unique identifier of the Object Target Collection. |
 **create_object_target_wto_body** | [**CreateObjectTargetWTOBody**](CreateObjectTargetWTOBody.md)|  |

### Return type

[**ObjectTargetJobResponse**](ObjectTargetJobResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The asynchronous job information. |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID  |  -  |
**401** | INVALID_TOKEN  |  -  |
**404** | OBJECT_TARGET_COLLECTION_NOT_FOUND  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **delete_object_target**
> delete_object_target(x_version, x_token, tc_id, target_id)

Delete Object Target

Delete a particular Object Target from your Object Target Collection.

### Example

```python
import time
import wikitude_studio_api_client
from wikitude_studio_api_client.api import object_target_api
from pprint import pprint
# Defining the host is optional and defaults to https://api-eu.wikitude.com/cloudrecognition
# See configuration.py for a list of all supported configuration parameters.
configuration = wikitude_studio_api_client.Configuration(
    host = "https://api-eu.wikitude.com/cloudrecognition"
)


# Enter a context with an instance of the API client
with wikitude_studio_api_client.ApiClient() as api_client:
    # Create an instance of the API class
    api_instance = object_target_api.ObjectTargetApi(api_client)
    x_version = "3" # str | The version of the API to be used. Must be set to 3.
    x_token = "X-Token_example" # str | Your Manager Token.
    tc_id = "tcId_example" # str | Unique identifier of the Object Target Collection.
    target_id = "targetId_example" # str | Unique identifier of the Object Target.

    # example passing only required values which don't have defaults set
    try:
        # Delete Object Target
        api_instance.delete_object_target(x_version, x_token, tc_id, target_id)
    except wikitude_studio_api_client.ApiException as e:
        print("Exception when calling ObjectTargetApi->delete_object_target: %s\n" % e)
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **x_version** | **str**| The version of the API to be used. Must be set to 3. |
 **x_token** | **str**| Your Manager Token. |
 **tc_id** | **str**| Unique identifier of the Object Target Collection. |
 **target_id** | **str**| Unique identifier of the Object Target. |

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**204** | Successful operation - Empty response body. |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID  |  -  |
**401** | INVALID_TOKEN  |  -  |
**404** | OBJECT_TARGET_COLLECTION_NOT_FOUND&lt;br/&gt; OBJECT_TARGET_NOT_FOUND  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **extend_object_target**
> ObjectTargetJobResponse extend_object_target(x_version, x_token, content_type, tc_id, target_id, extend_object_target_body)

Extend Object Target

Add source images to an existing target.

### Example

```python
import time
import wikitude_studio_api_client
from wikitude_studio_api_client.api import object_target_api
from wikitude_studio_api_client.model.extend_object_target_body import ExtendObjectTargetBody
from wikitude_studio_api_client.model.object_target_job_response import ObjectTargetJobResponse
from pprint import pprint
# Defining the host is optional and defaults to https://api-eu.wikitude.com/cloudrecognition
# See configuration.py for a list of all supported configuration parameters.
configuration = wikitude_studio_api_client.Configuration(
    host = "https://api-eu.wikitude.com/cloudrecognition"
)


# Enter a context with an instance of the API client
with wikitude_studio_api_client.ApiClient() as api_client:
    # Create an instance of the API class
    api_instance = object_target_api.ObjectTargetApi(api_client)
    x_version = "3" # str | The version of the API to be used. Must be set to 3.
    x_token = "X-Token_example" # str | Your Manager Token.
    content_type = "Content-Type_example" # str | The Content Type of the body. Must be set to application/json.
    tc_id = "tcId_example" # str | Unique identifier of the Object Target Collection.
    target_id = "targetId_example" # str | Unique identifier of the Object Target.
    extend_object_target_body = ExtendObjectTargetBody(
        images=[
            "https://wikitudeUrl.com/objectImage.jpg",
        ],
        fov=60,
    ) # ExtendObjectTargetBody | 

    # example passing only required values which don't have defaults set
    try:
        # Extend Object Target
        api_response = api_instance.extend_object_target(x_version, x_token, content_type, tc_id, target_id, extend_object_target_body)
        pprint(api_response)
    except wikitude_studio_api_client.ApiException as e:
        print("Exception when calling ObjectTargetApi->extend_object_target: %s\n" % e)
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **x_version** | **str**| The version of the API to be used. Must be set to 3. |
 **x_token** | **str**| Your Manager Token. |
 **content_type** | **str**| The Content Type of the body. Must be set to application/json. |
 **tc_id** | **str**| Unique identifier of the Object Target Collection. |
 **target_id** | **str**| Unique identifier of the Object Target. |
 **extend_object_target_body** | [**ExtendObjectTargetBody**](ExtendObjectTargetBody.md)|  |

### Return type

[**ObjectTargetJobResponse**](ObjectTargetJobResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The asynchronous job information. |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID&lt;br/&gt; TARGET_NOT_EXTENDABLE  |  -  |
**401** | INVALID_TOKEN  |  -  |
**404** | OBJECT_TARGET_COLLECTION_NOT_FOUND  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_object_target**
> ObjectTargetResponse get_object_target(x_version, x_token, tc_id, target_id)

Get Object Target

Request a specific Object Targets from your account.

### Example

```python
import time
import wikitude_studio_api_client
from wikitude_studio_api_client.api import object_target_api
from wikitude_studio_api_client.model.object_target_response import ObjectTargetResponse
from pprint import pprint
# Defining the host is optional and defaults to https://api-eu.wikitude.com/cloudrecognition
# See configuration.py for a list of all supported configuration parameters.
configuration = wikitude_studio_api_client.Configuration(
    host = "https://api-eu.wikitude.com/cloudrecognition"
)


# Enter a context with an instance of the API client
with wikitude_studio_api_client.ApiClient() as api_client:
    # Create an instance of the API class
    api_instance = object_target_api.ObjectTargetApi(api_client)
    x_version = "3" # str | The version of the API to be used. Must be set to 3.
    x_token = "X-Token_example" # str | Your Manager Token.
    tc_id = "tcId_example" # str | Unique identifier of the Object Target Collection.
    target_id = "targetId_example" # str | Unique identifier of the Object Target.

    # example passing only required values which don't have defaults set
    try:
        # Get Object Target
        api_response = api_instance.get_object_target(x_version, x_token, tc_id, target_id)
        pprint(api_response)
    except wikitude_studio_api_client.ApiException as e:
        print("Exception when calling ObjectTargetApi->get_object_target: %s\n" % e)
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **x_version** | **str**| The version of the API to be used. Must be set to 3. |
 **x_token** | **str**| Your Manager Token. |
 **tc_id** | **str**| Unique identifier of the Object Target Collection. |
 **target_id** | **str**| Unique identifier of the Object Target. |

### Return type

[**ObjectTargetResponse**](ObjectTargetResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The requested Object Target. |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID  |  -  |
**401** | INVALID_TOKEN  |  -  |
**404** | OBJECT_TARGET_COLLECTION_NOT_FOUND  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_object_target_status**
> ObjectTargetJobResponse get_object_target_status(x_version, x_token, tc_id, generation_id)

Status - Object Target Generation Information

Retrieves information status about a particular scheduled Object Target creation.

### Example

```python
import time
import wikitude_studio_api_client
from wikitude_studio_api_client.api import object_target_api
from wikitude_studio_api_client.model.object_target_job_response import ObjectTargetJobResponse
from pprint import pprint
# Defining the host is optional and defaults to https://api-eu.wikitude.com/cloudrecognition
# See configuration.py for a list of all supported configuration parameters.
configuration = wikitude_studio_api_client.Configuration(
    host = "https://api-eu.wikitude.com/cloudrecognition"
)


# Enter a context with an instance of the API client
with wikitude_studio_api_client.ApiClient() as api_client:
    # Create an instance of the API class
    api_instance = object_target_api.ObjectTargetApi(api_client)
    x_version = "3" # str | The version of the API to be used. Must be set to 3.
    x_token = "X-Token_example" # str | Your Manager Token.
    tc_id = "tcId_example" # str | Unique identifier of the Object Target Collection.
    generation_id = "generationId_example" # str | Unique identifier of the asynchronous job created by a generation endpoint.

    # example passing only required values which don't have defaults set
    try:
        # Status - Object Target Generation Information
        api_response = api_instance.get_object_target_status(x_version, x_token, tc_id, generation_id)
        pprint(api_response)
    except wikitude_studio_api_client.ApiException as e:
        print("Exception when calling ObjectTargetApi->get_object_target_status: %s\n" % e)
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **x_version** | **str**| The version of the API to be used. Must be set to 3. |
 **x_token** | **str**| Your Manager Token. |
 **tc_id** | **str**| Unique identifier of the Object Target Collection. |
 **generation_id** | **str**| Unique identifier of the asynchronous job created by a generation endpoint. |

### Return type

[**ObjectTargetJobResponse**](ObjectTargetJobResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The asynchronous job information. |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID  |  -  |
**401** | INVALID_TOKEN  |  -  |
**404** | GENERATION_NOT_FOUND  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_object_targets**
> [ObjectTargetResponse] get_object_targets(x_version, x_token, tc_id)

Get Object Targets

Request all Object Targets in a Target Collection.

### Example

```python
import time
import wikitude_studio_api_client
from wikitude_studio_api_client.api import object_target_api
from wikitude_studio_api_client.model.object_target_response import ObjectTargetResponse
from pprint import pprint
# Defining the host is optional and defaults to https://api-eu.wikitude.com/cloudrecognition
# See configuration.py for a list of all supported configuration parameters.
configuration = wikitude_studio_api_client.Configuration(
    host = "https://api-eu.wikitude.com/cloudrecognition"
)


# Enter a context with an instance of the API client
with wikitude_studio_api_client.ApiClient() as api_client:
    # Create an instance of the API class
    api_instance = object_target_api.ObjectTargetApi(api_client)
    x_version = "3" # str | The version of the API to be used. Must be set to 3.
    x_token = "X-Token_example" # str | Your Manager Token.
    tc_id = "tcId_example" # str | Unique identifier of the Object Target Collection.

    # example passing only required values which don't have defaults set
    try:
        # Get Object Targets
        api_response = api_instance.get_object_targets(x_version, x_token, tc_id)
        pprint(api_response)
    except wikitude_studio_api_client.ApiException as e:
        print("Exception when calling ObjectTargetApi->get_object_targets: %s\n" % e)
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **x_version** | **str**| The version of the API to be used. Must be set to 3. |
 **x_token** | **str**| Your Manager Token. |
 **tc_id** | **str**| Unique identifier of the Object Target Collection. |

### Return type

[**[ObjectTargetResponse]**](ObjectTargetResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | Array of all Object Targets. |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID  |  -  |
**401** | INVALID_TOKEN  |  -  |
**404** | OBJECT_TARGET_COLLECTION_NOT_FOUND  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **rename_object_target**
> ObjectTargetJobResponse rename_object_target(x_version, x_token, content_type, tc_id, target_id, rename_object_target_body)

Rename Object Target

Rename an existing target.

### Example

```python
import time
import wikitude_studio_api_client
from wikitude_studio_api_client.api import object_target_api
from wikitude_studio_api_client.model.rename_object_target_body import RenameObjectTargetBody
from wikitude_studio_api_client.model.object_target_job_response import ObjectTargetJobResponse
from pprint import pprint
# Defining the host is optional and defaults to https://api-eu.wikitude.com/cloudrecognition
# See configuration.py for a list of all supported configuration parameters.
configuration = wikitude_studio_api_client.Configuration(
    host = "https://api-eu.wikitude.com/cloudrecognition"
)


# Enter a context with an instance of the API client
with wikitude_studio_api_client.ApiClient() as api_client:
    # Create an instance of the API class
    api_instance = object_target_api.ObjectTargetApi(api_client)
    x_version = "3" # str | The version of the API to be used. Must be set to 3.
    x_token = "X-Token_example" # str | Your Manager Token.
    content_type = "Content-Type_example" # str | The Content Type of the body. Must be set to application/json.
    tc_id = "tcId_example" # str | Unique identifier of the Object Target Collection.
    target_id = "targetId_example" # str | Unique identifier of the Object Target.
    rename_object_target_body = RenameObjectTargetBody(
        name="Some Target",
        real_world_scale=42,
    ) # RenameObjectTargetBody | 

    # example passing only required values which don't have defaults set
    try:
        # Rename Object Target
        api_response = api_instance.rename_object_target(x_version, x_token, content_type, tc_id, target_id, rename_object_target_body)
        pprint(api_response)
    except wikitude_studio_api_client.ApiException as e:
        print("Exception when calling ObjectTargetApi->rename_object_target: %s\n" % e)
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **x_version** | **str**| The version of the API to be used. Must be set to 3. |
 **x_token** | **str**| Your Manager Token. |
 **content_type** | **str**| The Content Type of the body. Must be set to application/json. |
 **tc_id** | **str**| Unique identifier of the Object Target Collection. |
 **target_id** | **str**| Unique identifier of the Object Target. |
 **rename_object_target_body** | [**RenameObjectTargetBody**](RenameObjectTargetBody.md)|  |

### Return type

[**ObjectTargetJobResponse**](ObjectTargetJobResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**202** | The asynchronous job information. |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID&lt;br/&gt; INVALID_PROPERTY  |  -  |
**401** | INVALID_TOKEN  |  -  |
**404** | OBJECT_TARGET_COLLECTION_NOT_FOUND&lt;br/&gt; OBJECT_TARGET_NOT_FOUND  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

